-- *******************************************************************************
-- PROCEDIMIENTO DE CARGA EN EL DW DE LOS REGISTROS NUEVOS DE LA TABLA EMPRESA
create or replace
PROCEDURE ADMIN_BBDD.ETL_DIM_EMPRESA
AS
   CURSOR cursor_dimensiones
   IS
      SELECT EMPRESA."ID_EMPRESA", EMPRESA."CIF", EMPRESA."NOMBRE", EMPRESA."EMAIL", EMPRESA."TELEFONO"
        FROM ADMIN_BBDD."EMPRESA" EMPRESA
       WHERE EMPRESA."ID_EMPRESA" NOT IN (SELECT "ID_EMPRESA"
                                 FROM "DIM_EMPRESA");
BEGIN
   FOR registro_nuevo IN cursor_dimensiones
   LOOP
      INSERT INTO "DIM_EMPRESA"
                  ("ID_EMPRESA", "CIF", "NOMBRE", "EMAIL", "TELEFONO")
      VALUES (registro_nuevo."ID_EMPRESA", registro_nuevo."CIF", registro_nuevo."NOMBRE", registro_nuevo."EMAIL", registro_nuevo."TELEFONO");
   END LOOP;
EXCEPTION
   WHEN OTHERS
   THEN
      raise_application_error (-20001, SQLERRM);
END "ETL_DIM_EMPRESA";
/



-- *******************************************************************************
-- PROCEDIMIENTO DE CARGA EN EL DW DE LOS REGISTROS NUEVOS DE LA TABLA EXPERIENCIA
create or replace
PROCEDURE ADMIN_BBDD.ETL_DIM_EXPERIENCIA
AS
   CURSOR cursor_dimensiones
   IS
      SELECT EXPERIENCIA."ID_EXPERIENCIA", EXPERIENCIA."ID_OFERTA", EXPERIENCIA."ID_PUESTO"
        FROM ADMIN_BBDD."EXPERIENCIA" EXPERIENCIA
       WHERE EXPERIENCIA."ID_EXPERIENCIA" NOT IN (SELECT "ID_EXPERIENCIA"
                                 FROM "DIM_EXPERIENCIA");
BEGIN
   FOR registro_nuevo IN cursor_dimensiones
   LOOP
      INSERT INTO "DIM_EXPERIENCIA"
                  ("ID_EXPERIENCIA", "ID_OFERTA", "ID_PUESTO")
      VALUES (registro_nuevo."ID_EXPERIENCIA", registro_nuevo."ID_OFERTA", registro_nuevo."ID_PUESTO"
                  );
   END LOOP;
EXCEPTION
   WHEN OTHERS
   THEN
      raise_application_error (-20001, SQLERRM);
END "ETL_DIM_EXPERIENCIA";
/

-- *******************************************************************************
-- PROCEDIMIENTO DE CARGA EN EL DW DE LOS REGISTROS NUEVOS DE LA TABLA PUESTOS
create or replace
PROCEDURE ADMIN_BBDD.ETL_DIM_PUESTO
AS
   CURSOR cursor_dimensiones
   IS
      SELECT PUESTO."ID_PUESTO", PUESTO."DESCRIPCION", PUESTO."ID_TIPO"
        FROM ADMIN_BBDD."PUESTO" PUESTO
       WHERE PUESTO."ID_PUESTO" NOT IN (SELECT "ID_PUESTO"
                                 FROM "DIM_PUESTO");
BEGIN
   FOR registro_nuevo IN cursor_dimensiones
   LOOP
      INSERT INTO "DIM_PUESTO"
                  ("ID_PUESTO", "DESCRIPCION", "ID_TIPO")
      VALUES (registro_nuevo."ID_PUESTO", registro_nuevo."DESCRIPCION", registro_nuevo."ID_TIPO"
                  );
   END LOOP;
EXCEPTION
   WHEN OTHERS
   THEN
      raise_application_error (-20001, SQLERRM);
END "ETL_DIM_PUESTO";
/


-- *******************************************************************************
-- PROCEDIMIENTO DE CARGA EN EL DW DE LOS REGISTROS NUEVOS DE LA TABLA TIPO_PUESTO
create or replace
PROCEDURE ADMIN_BBDD.ETL_DIM_TIPO_PUESTO
AS
   CURSOR cursor_dimensiones
   IS
      SELECT TIPO_PUESTO."ID_TIPO", TIPO_PUESTO."DESCRIPCION"
        FROM ADMIN_BBDD."TIPO_PUESTO" TIPO_PUESTO
       WHERE TIPO_PUESTO."ID_TIPO" NOT IN (SELECT "ID_TIPO"
                                 FROM "DIM_TIPO_PUESTO");
BEGIN
   FOR registro_nuevo IN cursor_dimensiones
   LOOP
      INSERT INTO "DIM_TIPO_PUESTO"
                  ("ID_TIPO", "DESCRIPCION")
      VALUES (registro_nuevo."ID_TIPO", registro_nuevo."DESCRIPCION");
   END LOOP;
EXCEPTION
   WHEN OTHERS
   THEN
      raise_application_error (-20001, SQLERRM);
END "ETL_DIM_TIPO_PUESTO";
/


-- ************************************************************************************
-- PROCEDIMIENTO DE CARGA EN EL DW DE LOS REGISTROS NUEVOS DE LA TABLA DE HECHOS OFERTA
create or replace
PROCEDURE ADMIN_BBDD.ETL_OFERTAS
AS
   CURSOR cursor_dimensiones
   IS
      SELECT OFERTA."ID_OFERTA", OFERTA."REMUNERACION", OFERTA."PRIORIDAD", 
				OFERTA."FECHA_INICIO", OFERTA."FECHA_ADJUDICACION", 
				OFERTA."ID_PUESTO", OFERTA."ID_EMPRESA"    
        FROM ADMIN_BBDD."OFERTA" OFERTA
       WHERE OFERTA."ID_OFERTA" NOT IN (SELECT "ID_OFERTA"
                                 FROM "HECHO_OFERTA");
BEGIN
   FOR registro_nuevo IN cursor_dimensiones
   LOOP
      INSERT INTO "HECHO_OFERTA"
                  ("ID_OFERTA", "REMUNERACION","PRIORIDAD","FECHA_INICIO", "FECHA_ADJUDICACION", "ID_PUESTO", "ID_EMPRESA")
      VALUES (registro_nuevo."ID_OFERTA", registro_nuevo."REMUNERACION", registro_nuevo."PRIORIDAD", 
				registro_nuevo."FECHA_INICIO", registro_nuevo."FECHA_ADJUDICACION", 
				registro_nuevo."ID_PUESTO", registro_nuevo."ID_EMPRESA");
   END LOOP;
EXCEPTION
   WHEN OTHERS
   THEN
      raise_application_error (-20001, SQLERRM);
END "ETL_OFERTAS";
/


-- ************************************************************************************
-- PROCEDIMIENTO DE CONSULTA DEL CONTENIDO DE LA TABLA DE HECHOS OFERTA
create or replace
PROCEDURE ADMIN_BBDD.CONSULTA_DW
AS
   CURSOR cursor_dimensiones
   IS
      SELECT OFERTA."ID_OFERTA", OFERTA."REMUNERACION", OFERTA."PRIORIDAD", 
				OFERTA."FECHA_INICIO", OFERTA."FECHA_ADJUDICACION", 
				OFERTA."ID_PUESTO", OFERTA."ID_EMPRESA"    
        FROM ADMIN_BBDD."OFERTA" OFERTA
       WHERE OFERTA."ID_OFERTA" NOT IN (SELECT "ID_OFERTA"
                                 FROM "HECHO_OFERTA");
BEGIN
   FOR registro_nuevo IN cursor_dimensiones
   LOOP
      dbms_output.put_line('CONTENIDO DE LA TABLA DE HECHOS "HECHO_OFERTA"' || registro_nuevo."ID_OFERTA"||
	  registro_nuevo."REMUNERACION"|| registro_nuevo."PRIORIDAD" || registro_nuevo."FECHA_INICIO"|| 
	  registro_nuevo."FECHA_ADJUDICACION" || registro_nuevo."ID_PUESTO" || registro_nuevo."ID_EMPRESA");
   END LOOP;
EXCEPTION
   WHEN OTHERS
   THEN
      raise_application_error (-20001, SQLERRM);
END "CONSULTA_DW";
/
